pub fn parse(source: &str) -> Result<Program, ParseError>Expand description
Parse a complete shell source string into a Program AST.
pub fn parse(source: &str) -> Result<Program, ParseError>Parse a complete shell source string into a Program AST.